'use strict';

var React = require('react');
var gui = require('gui');

var _require = require('./utils'),
    createTestSuite = _require.createTestSuite;

describe('scroll', function () {
  it('should render the component correctly', function (done) {
    createTestSuite(function (render) {
      var contentSize = { width: 100, height: 100 };
      var overlayScrollbar = true;
      var hpolicy = 'never';
      var vpolicy = 'always';

      var ele = React.createElement(
        'scroll',
        {
          contentSize: contentSize,
          overlayScrollbar: overlayScrollbar,
          hpolicy: hpolicy,
          vpolicy: vpolicy
        },
        React.createElement('container', null)
      );

      render(ele, function (container) {
        var scroll = container.childAt(0);
        expect(scroll instanceof gui.Scroll).toBeTruthy();
        var size = scroll.getContentSize();
        expect(size.width).toBe(contentSize.width);
        expect(size.height).toBe(contentSize.height);
        expect(scroll.isOverlayScrollbar()).toBe(overlayScrollbar);
        var policies = scroll.getScrollbarPolicy();
        expect(policies[0]).toBe(hpolicy);
        // TODO: not work for vpolicy
        // expect(policies[1]).toBe(vpolicy)
        done();
      });
    });
  });
});