'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
var Reconciler = require('react-reconciler');

var _require = require('./components'),
    Components = _require.Components,
    hasComponent = _require.hasComponent;

var _require2 = require('./utils'),
    emptyObject = _require2.emptyObject,
    now = _require2.now,
    scheduleDeferredCallback = _require2.scheduleDeferredCallback;

function appendInitialChild(parentInstance, child) {
  // TODO: views that do not support addChildView
  parentInstance.addChildView(child);
}

function createInstance(type, props, internalInstanceHandle) {
  if (!hasComponent(type)) {
    throw new Error('receive invalid type: ' + type);
  }

  // console.error('internalInstanceHandle', internalInstanceHandle)

  var Comp = Components[type];

  return new Comp(props);
}

// eslint-disable-next-line
function finalizeInitialChildren(docElement, type, props) {
  // console.log('finalizeInitialChildren')
  return false;
}

function getPublicInstance(instance) {
  return instance._ele;
}

function prepareForCommit() {
  // console.log('getPublicInstance')
}

function prepareUpdate() {
  // always update
  return true;
}

function resetAfterCommit() {}

function getRootHostContext() {
  return emptyObject;
}

function getChildHostContext() {
  return emptyObject;
}

// TODO: utilize the text content
function shouldSetTextContent() {
  return false;
}

function resetTextContent() {}

function createTextInstance() {
  return null;
}

// eslint-disable-next-line
function shouldDeprioritizeSubtree(type, props) {
  return false;
}

// Mutation
function appendChild(parentInstance, child) {
  if (typeof parentInstance.addChildView !== 'function') {
    throw new Error('expect the instance to be an gui container');
  }

  parentInstance.addChildView(child);
}

function appendChildToContainer(parentInstance, child) {
  if (typeof parentInstance.addChildView !== 'function') {
    throw new Error('expect the instance to be an gui container');
  }

  parentInstance.addChildView(child.getElement());
}

function removeChild(parentInstance, child) {
  parentInstance.removeChildView(child);
}

function removeChildFromContainer(parentInstance, child) {
  parentInstance.removeChildView(child);
}

function insertBefore(parentInstance, child, beforeChild) {
  parentInstance.insertBefore(child, beforeChild);
}

// TODO: what's the "updatePayload"?
function commitUpdate(instance, updatePayload, type, oldProps, newProps) {
  // console.log('instance, updatePayload', instance, updatePayload, type, oldProps, newProps)
  instance.update(oldProps, newProps);
}

function commitMount(instance, updatePayload, type, oldProps, newProps) {
  // console.log('commitMount')
}

function commitTextUpdate(textInstance, oldText, newText) {
  // console.log('commitTextUpdate')
}

var YueRenderer = exports.YueRenderer = Reconciler({
  appendInitialChild: appendInitialChild,

  createInstance: createInstance,

  createTextInstance: createTextInstance,

  finalizeInitialChildren: finalizeInitialChildren,

  getPublicInstance: getPublicInstance,

  prepareForCommit: prepareForCommit,

  prepareUpdate: prepareUpdate,

  resetAfterCommit: resetAfterCommit,

  resetTextContent: resetTextContent,

  getRootHostContext: getRootHostContext,

  getChildHostContext: getChildHostContext,

  shouldSetTextContent: shouldSetTextContent,

  scheduleDeferredCallback: scheduleDeferredCallback,

  shouldDeprioritizeSubtree: shouldDeprioritizeSubtree,

  now: now,

  mutation: {
    appendChild: appendChild,
    appendChildToContainer: appendChildToContainer,
    removeChild: removeChild,
    removeChildFromContainer: removeChildFromContainer,
    insertBefore: insertBefore,
    commitUpdate: commitUpdate,
    commitMount: commitMount,
    commitTextUpdate: commitTextUpdate
  }
});

function render(element, guiContainer, callback) {
  var root = guiContainer._reactRootContainer;

  if (!root) {
    // Remove all children of the guiContainer
    var childCount = guiContainer.childCount();

    for (var i = 0; i < childCount; i += 1) {
      guiContainer.removeChildView(guiContainer.childAt(0));
    }

    var newRoot = YueRenderer.createContainer(guiContainer);
    // eslint-disable-next-line
    root = guiContainer._reactRootContainer = newRoot;
  }

  return YueRenderer.updateContainer(element, root, null, callback);
}

module.exports = {
  render: render
};